==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFInverseOperatorDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFINVERSEOPERATOR_DECL_HPP
#define TSFINVERSEOPERATOR_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFLinearOperatorDecl.hpp"
#include "Thyra_ZeroLinearOpBase.hpp"
#include "TSFOpWithBackwardsCompatibleApply.hpp"
#include "Thyra_VectorSpaceBase.hpp"

#include "Teuchos_RefCountPtr.hpp"
#include "TSFLinearSolverDecl.hpp"
#include "TSFSolverState.hpp"

namespace TSFExtended
{
using Teuchos::RCP;

/** 
 * TSFInverseOperator represents the inverse of some other operator.  An
 * inverse operator object will contain an operator and a solver.  The 
 * operator data member is the operator whose inverse this represents.  The
 * solver data member is the solver that will be used in applying the
 * inverse.  If the solver is null, the operator is assumed to have
 * self-contained ability to solve systems, as for a dense matrix that 
 * does solves by factoring and backsolves.
 */
template <class Scalar> 
class InverseOperator : public OpWithBackwardsCompatibleApply<Scalar>,
  public Printable
{
public:
  /**
   * Ctor with a linear operator and a solver specified.
   */
  InverseOperator(const LinearOperator<Scalar>& op, 
    const LinearSolver<Scalar>& solver);

  /** Virtual dtor */
  virtual ~InverseOperator(){;}


  /** 
   * Compute alpha*M*x + beta*y, where M=*this.
   * @param M_trans specifies whether the operator is transposed:
   *                op(M) = M, for M_trans == NOTRANS
   *                op(M) = M', for M_trans == TRANS
   * @param x       vector of length this->domain()->dim()
   * @param y       vector of length this->range()->dim()
   * @param alpha   scalar multiplying M*x (default is 1.0)
   * @param beta    scalar multiplying y (default is 0.0)
   */
  virtual void generalApply(
    const Thyra::ETransp            M_trans,
    const Thyra::VectorBase<Scalar>    &x,
    Thyra::VectorBase<Scalar>          *y,
    const Scalar            alpha = 1.0,
    const Scalar            beta  = 0.0
    ) const ;

  /** 
   * Return the domain of the operator. 
   */
  virtual RCP<const Thyra::VectorSpaceBase<Scalar> > domain() const ;
    

  /** 
   * Return the range of the operator. 
   */
  virtual RCP<const Thyra::VectorSpaceBase<Scalar> > range() const ;

  /** */
  void print(std::ostream& os) const ;


private:
  const LinearOperator<Scalar> op_;
  const LinearSolver<Scalar> solver_;  
  std::string msg_;
};


/** */
template <class Scalar> 
LinearOperator<Scalar> 
inverse(const LinearOperator<Scalar>& op, 
  const LinearSolver<Scalar>& solver);
  

}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFInverseOperatorDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFINVERSEOPERATOR_DECL_HPP
#define TSFINVERSEOPERATOR_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFLinearOperatorDecl.hpp"
#include "Thyra_ZeroLinearOpBase.hpp"
#include "TSFOpWithBackwardsCompatibleApply.hpp"
#include "Thyra_VectorSpaceBase.hpp"

#include "Teuchos_RefCountPtr.hpp"
#include "TSFLinearSolverDecl.hpp"
#include "TSFSolverState.hpp"

namespace TSFExtended
{
using Teuchos::RCP;

/** 
 * TSFInverseOperator represents the inverse of some other operator.  An
 * inverse operator object will contain an operator and a solver.  The 
 * operator data member is the operator whose inverse this represents.  The
 * solver data member is the solver that will be used in applying the
 * inverse.  If the solver is null, the operator is assumed to have
 * self-contained ability to solve systems, as for a dense matrix that 
 * does solves by factoring and backsolves.
 */
template <class Scalar> 
class InverseOperator : public OpWithBackwardsCompatibleApply<Scalar>,
  public Printable
{
public:
  /**
   * Ctor with a linear operator and a solver specified.
   */
  InverseOperator(const LinearOperator<Scalar>& op, 
    const LinearSolver<Scalar>& solver);

  /** Virtual dtor */
  virtual ~InverseOperator(){;}


  /** 
   * Compute alpha*M*x + beta*y, where M=*this.
   * @param M_trans specifies whether the operator is transposed:
   *                op(M) = M, for M_trans == NOTRANS
   *                op(M) = M', for M_trans == TRANS
   * @param x       vector of length this->domain()->dim()
   * @param y       vector of length this->range()->dim()
   * @param alpha   scalar multiplying M*x (default is 1.0)
   * @param beta    scalar multiplying y (default is 0.0)
   */
  virtual void generalApply(
    const Thyra::EOpTransp            M_trans,
    const Thyra::VectorBase<Scalar>    &x,
    Thyra::VectorBase<Scalar>          *y,
    const Scalar            alpha = 1.0,
    const Scalar            beta  = 0.0
    ) const ;

  /** 
   * Return the domain of the operator. 
   */
  virtual RCP<const Thyra::VectorSpaceBase<Scalar> > domain() const ;
    

  /** 
   * Return the range of the operator. 
   */
  virtual RCP<const Thyra::VectorSpaceBase<Scalar> > range() const ;

  /** */
  void print(std::ostream& os) const ;


private:
  const LinearOperator<Scalar> op_;
  const LinearSolver<Scalar> solver_;  
  std::string msg_;
};


/** */
template <class Scalar> 
LinearOperator<Scalar> 
inverse(const LinearOperator<Scalar>& op, 
  const LinearSolver<Scalar>& solver);
  

}

#endif
